@@ -2,8 +2,8 @@
 
 # $2 = version
 # $3 = file
-DIR=jasperreports3.7-$2.orig
-TAR=../jasperreports3.7_$2+dfsg.orig.tar.gz
+DIR=jasperreports-$2.orig
+TAR=jasperreports_$2+dfsg.orig.tar.gz
 
 # clean up the upstream tarball
 tar zxf $3
